@@ -26,8 +26,8 @@ icon_aru=""
 icon_att=""
 icon_bel=""
 icon_bok=""
-icon_btd="" # bluethooth device
 icon_bth="" # bluetooth
+icon_cal=""
 icon_cam=""
 icon_cfg="" #configuration cog
 icon_chk=""
@@ -35,12 +35,14 @@ icon_chs="♜" #chess
 icon_clc="" #calculator
 icon_clk=""
 icon_cls="" #close
+icon_com="" # (Laptop) Computer (💻)
 icon_cpy=""
 icon_del="﫧" #delete
 icon_dir="" #directory folder
 icon_dof="" # dot off
 icon_don="" # dot on
 icon_dot="" # searching, connecting, etc.
+icon_drw="" # Drawing tablet
 icon_ear="" # earpiece
 icon_edt="" #editor
 icon_eml="" #email
@@ -53,6 +55,7 @@ icon_fil="" #file
 icon_fll="" #flashlight
 icon_flt="" #filter/pipe
 icon_fnd="" #search/find
+icon_gam="" # gaming controller (🎮)
 icon_glb="" #globe
 icon_gps='' #gps
 icon_grd=""
@@ -72,8 +75,9 @@ icon_mdd="" # modem disabled state
 icon_mic=""
 icon_mmc=""
 icon_mnu=""
-icon_mod="" # modem
+icon_mod="" # modem
 icon_mov=""
+icon_mse="" # computer mouse (🖱️)
 icon_msg="" #text
 icon_mus=""
 icon_mut="" #mute
@@ -88,6 +92,7 @@ icon_phn="" #phone
 icon_phx="" #hangup
 icon_plk="" # phone locked
 icon_pls=""
+icon_prn="🖶" # printer (🖨️)
 icon_prv="" #previous
 icon_pst=""
 icon_pwr="⏻" #power
@@ -119,7 +124,10 @@ icon_usr=""
 icon_vid="" #video
 icon_vim=''
 icon_wif=""
+icon_wfo="睊" # wifi off
+icon_wfh="" # wifi hotspot
 icon_win="" #window
+icon_wat="" # watch (⌚)
 icon_wn2=""
 icon_wrh=""
 icon_wtr="" #weather
