@@ -16,8 +16,7 @@ write_line() {
 
 get_title() {
 	title=""
-	# Process substitution because source won't work with data piped from stdin.
-	. <(head "$1" | grep '# title="[^\\"]*"' | sed 's/^# //g')
+	eval "$(head "$1" | grep '# title="[^\\"]*"' | sed 's/^# //g')"
 	if [ -n "$title" ]; then
 		echo "$title"
 	else
@@ -38,7 +37,7 @@ fi
 write_line "$icon_cfg Edit Userscripts" "sxmo_terminal.sh $EDITOR $XDG_CONFIG_HOME/sxmo/userscripts/*"
 
 # System Scripts
-find /usr/share/sxmo/appscripts -type f -o -type l | sort -f | while read -r script; do
+find "$(xdg_data_path sxmo/appscripts)" -type f -o -type l | sort -f | while read -r script; do
 	title="$(get_title "$script")"
 	write_line "$title" "$script"
 done
