@@ -13,13 +13,20 @@ echo "unlock" > "$SXMO_STATE"
 # Create xdg user directories, such as ~/Pictures
 xdg-user-dirs-update
 
-# Play a funky startup tune if you want (disabled by default)
-#mpv --quiet --no-video ~/welcome.ogg &
-
 sxmo_daemons.sh start daemon_manager superd -v
 
-sleep 2 # let time to superd to start correctly
+# let time to superd to start correctly
+while ! superctl status > /dev/null 2>&1; do
+	sleep 0.1
+done
 
+# Load our sound daemons
+# pipewire-pulse will start pipewire
+superctl start pipewire-pulse
+superctl start wireplumber
+
+# mako/dunst are required for warnings.
+# load some other little things here too.
 case "$SXMO_WM" in
 	sway)
 		superctl start mako
@@ -38,9 +45,6 @@ case "$SXMO_WM" in
 		fi
 		superctl start "$1"
 
-		# Set a pretty wallpaper
-		feh --bg-fill "$(xdg_data_path sxmo/background.jpg)"
-
 		superctl start autocutsel
 		superctl start autocutsel-primary
 		superctl start sxmo-x11-status
@@ -48,22 +52,20 @@ case "$SXMO_WM" in
 		;;
 esac
 
-if [ -f "${SXMO_MMS_BASE_DIR:-"$HOME"/.mms/modemmanager}/mms" ]; then
-	superctl start mmsd
-fi
-
-if [ -f "${SXMO_VVM_BASE_DIR:-"$HOME"/.vvm/modemmanager}/vvm" ]; then
-	superctl start vvmd
-fi
-
-# Start the desktop widget (e.g. clock)
-superctl start sxmo_desktop_widget
-
 # Periodically update some status bar components
 sxmo_hook_statusbar.sh all
 sxmo_daemons.sh start statusbar_periodics sxmo_run_aligned.sh 60 \
 	sxmo_hook_statusbar.sh periodics
 
+# To setup initial lock state
+sxmo_hook_unlock.sh
+
+# Turn on the dbus-monitors for modem-related tasks
+sxmo_daemons.sh start modem_monitor sxmo_modemmonitor.sh
+
+# Start the desktop widget (e.g. clock)
+superctl start sxmo_desktop_widget
+
 # Monitor the battery
 superctl start sxmo_battery_monitor
 
@@ -73,20 +75,28 @@ superctl start sxmo_networkmonitor
 # The daemon that display notifications popup messages
 superctl start sxmo_notificationmonitor
 
-# To setup initial lock state
-sxmo_hook_unlock.sh
+# monitor for headphone for statusbar
+superctl start sxmo_soundmonitor
 
-superctl start pipewire
-superctl start pipewire-pulse
-superctl start wireplumber
+# Play a funky startup tune if you want (disabled by default)
+#mpv --quiet --no-video ~/welcome.ogg &
 
-(
-	sleep 5 # let some time to pipewire
-	superctl start callaudiod
+# Set a background image: edit ~/.config/sxmo/sway or ~/.config/sxmo/xinit
 
-	# Turn on the dbus-monitors for modem-related tasks
-	sxmo_daemons.sh start modem_monitor sxmo_modemmonitor.sh
-) &
+# mmsd and vvmd
+if [ -f "${SXMO_MMS_BASE_DIR:-"$HOME"/.mms/modemmanager}/mms" ]; then
+	superctl start mmsd
+fi
+
+if [ -f "${SXMO_VVM_BASE_DIR:-"$HOME"/.vvm/modemmanager}/vvm" ]; then
+	superctl start vvmd
+fi
+
+# add some warnings if things are not setup correctly
+deviceprofile="$(command -v "sxmo_deviceprofile_$SXMO_DEVICE_NAME.sh")"
+
+[ -f "$deviceprofile" ] || sxmo_notify_user.sh --urgency=critical \
+	"No deviceprofile found $SXMO_DEVICE_NAME. See: https://sxmo.org/deviceprofile"
 
 sxmo_migrate.sh state || sxmo_notify_user.sh --urgency=critical \
 	"Config needs migration" "$? file(s) in your sxmo configuration are out of date and disabled - using defaults until you migrate (run sxmo_migrate.sh)"
