@@ -2,6 +2,8 @@
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
+# include common definitions
+# shellcheck source=scripts/core/sxmo_common.sh
 . sxmo_common.sh
 
 UNSUSPENDREASON="$1"
@@ -17,8 +19,6 @@ if [ "$UNSUSPENDREASON" != "modem" ]; then
 	fi
 fi
 
-sxmo_hook_statusbar.sh time
-
 if [ "$UNSUSPENDREASON" = "rtc" ] || [ "$UNSUSPENDREASON" = "usb power" ]; then
 	if grep -q screenoff "$XDG_RUNTIME_DIR/sxmo.state"; then
 		# We stopped it in presuspend
