@@ -45,4 +45,5 @@ else
 	esac
 fi
 
-sxmo_superd_signal.sh sxmo_desktop_widget -USR2
+sxmo_daemons.sh start periodic_state_mutex_check \
+	sxmo_run_aligned.sh 60 sxmo_uniq_exec.sh sxmo_hook_check_state_mutexes.sh
