@@ -4,4 +4,5 @@
 tmpfile=$(mktemp /tmp/st-edit.XXXXXX)
 trap  'rm "$tmpfile"' 0 1 15
 cat > "$tmpfile"
-sxmo_terminal.sh "$EDITOR" "$tmpfile"
+# shellcheck disable=SC2086
+sxmo_terminal.sh $EDITOR "$tmpfile"
