@@ -2,6 +2,9 @@
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
+# shellcheck source=scripts/core/sxmo_common.sh
+. sxmo_common.sh
+
 inputs="
 	${SXMO_POWER_BUTTON:-"0:0:axp20x-pek"}
 	${SXMO_VOLUME_BUTTON:-"1:1:1c21800.lradc"}
@@ -15,8 +18,8 @@ setup_xkb() {
 
 swaymsg -t subscribe -m "['mode']" | while read -r message; do
 	if printf %s "$message" | grep -q menu; then
-		setup_xkb /usr/share/sxmo/sway/xkb_mobile_movement_buttons
+		setup_xkb "$(xdg_data_path sxmo/xkb/xkb_mobile_movement_buttons)"
 	else
-		setup_xkb /usr/share/sxmo/sway/xkb_mobile_normal_buttons
+		setup_xkb "$(xdg_data_path sxmo/xkb/xkb_mobile_normal_buttons)"
 	fi
 done
