@@ -25,9 +25,10 @@ change_arch() {
 }
 
 menu() {
+	zoneinfo_dir=$(xdg_data_path zoneinfo)
 	T="$(
-		find /usr/share/zoneinfo -type f |
-		sed  's#^/usr/share/zoneinfo/##g' |
+		find "$zoneinfo_dir" -type f |
+		sed  "s#^${zoneinfo_dir}/##g" |
 		sort |
 		sxmo_dmenu_with_kb.sh -p Timezone -i
 	)" || exit 0
@@ -41,6 +42,7 @@ if [ $# -gt 0 ]; then
 	case "$OS" in
 		alpine|postmarketos) change_alpine "$@";;
 		arch|archarm) change_arch "$@";;
+		nixos) echo "Change the timezone in configuration.nix with time.timeZone = \"[timezone]\"";;
 		*) echo "Changing the timezone isn't implemented on your distro yet";;
 	esac
 else
