@@ -7,3 +7,5 @@ export SXMO_DISABLE_LEDS="1"
 export SXMO_MONITOR="0:0:generic_ft5x06_(8d)"
 export SXMO_POWER_BUTTON="0:0:pm8941_pwrkey"
 export SXMO_VOLUME_BUTTON="1:1:GPIO_Buttons 0:0:pm8941_resin"
+export SXMO_VIBRATE_DEV="/dev/input/by-path/platform-200f000.spmi-platform-200f000.spmi:pmic@1:vibrator@c000-event"
+export SXMO_SWAY_SCALE="2"
