@@ -2,6 +2,12 @@
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
+case "$1" in
+	*.json)
+		# we ignore json files
+		exit
+esac
+
 comment="#"
 case "$(busybox head -n1 "$1")" in
 	!*)
